using Genesyslab.Desktop.Infrastructure;
using Genesyslab.Desktop.Infrastructure.DependencyInjection;
using Genesyslab.Desktop.Modules.Windows.Event;
using Genesyslab.Platform.Commons.Logging;
using Microsoft.Practices.Composite.Events;
using Microsoft.Practices.Composite.Wpf.Events;


namespace Genesyslab.Desktop.Modules.Custom
{
    public class CustomModule : IModule
    {
        readonly IObjectContainer container_ = null;
        readonly IViewEventManager viewEventManager_ = null;
        readonly IEventAggregator eventAggregator_ = null;
        private  ILogger log_ = null;

        public CustomModule(IObjectContainer container, IViewEventManager viewEventManager, 
                            IEventAggregator eventAggregator, ILogger log)
        {
            this.container_ = container;
            this.eventAggregator_ = eventAggregator;
            this.viewEventManager_ = viewEventManager;

            this.log_ = log.CreateChildLogger("CustomModule");
        }

        public void Initialize()
        {
            viewEventManager_.Subscribe(MyEventHandler);
        }

        void MyEventHandler(object eventObject)
        {
            string eventMessage = eventObject as string;
            if (eventMessage != null)
            {
                switch (eventMessage)
                {
                    case "Loggin":
                        eventAggregator_.GetEvent<GotFocusCaseEvent>().Subscribe(SelectionEventHandler, ThreadOption.UIThread);
                        break;
                    case "Logout":
                        viewEventManager_.Unsubscribe(MyEventHandler);
                        break;
                }
            }
        }

        void SelectionEventHandler(object eventObject)
        {
            FocusCaseEvent selectedCaseEvent = eventObject as FocusCaseEvent;

            if (selectedCaseEvent != null && selectedCaseEvent.Case != null)
            {
                log_.DebugFormat("GotFocusCaseEvent - Case {0} got the focus", selectedCaseEvent.Case.CaseId);
            }
        }
    }
}
